@@ -10,17 +10,32 @@ import os
 import re
 import json
 import types
+import shutil
 import urllib
 import urllib2
 import logging
+from itertools import product
 from tempfile import NamedTemporaryFile
 
+# Optional dependencies.
 try:
     import pyfits
     pyfits = pyfits
 except ImportError:
     pyfits = None
 
+try:
+    import numpy as np
+    np = np
+except ImportError:
+    np = None
+
+try:
+    import matplotlib.pyplot as pl
+    pl = pl
+except ImportError:
+    pl = None
+
 from .config import KPLR_ROOT
 from . import mast
 
@@ -645,10 +660,16 @@ class _datafile(Model):
         f.flush()
         os.fsync(f.fileno())
         f.close()
-        os.rename(f.name, filename)
+        shutil.move(f.name, filename)
 
         return self
 
+    def plot(self):
+        if np is None:
+            raise ImportError("numpy is required for plotting.")
+        if pl is None:
+            raise ImportError("matplotlib is required for plotting.")
+
 
 class LightCurve(_datafile):
     """
@@ -661,6 +682,54 @@ class LightCurve(_datafile):
     suffixes = ["llc", "slc"]
     filetype = ".fits"
 
+    def plot(self):
+        """
+        Make a simple diagnostic plot of the light curve.
+
+        :return fig:
+            A :class:`matplotlib.Figure` object containing the plot.
+
+        """
+        super(LightCurve, self).plot()
+
+        # Load the data.
+        with self.open() as f:
+            data = f[1].data
+        time, sapflux, pdcflux, qual = (data["time"], data["sap_flux"],
+                                        data["pdcsap_flux"],
+                                        data["sap_quality"])
+
+        # Set up the figure.
+        fig, axes = pl.subplots(2, 1, figsize=(6, 6))
+        fig.subplots_adjust(left=0.17, top=0.99, right=0.99,
+                            wspace=0.0, hspace=0.0)
+
+        # Plot the data.
+        m = np.isfinite(time)
+        xlim = [np.min(time[m]), np.max(time[m])]
+        for i, (f, nm) in enumerate(zip([sapflux, pdcflux],
+                                        ["sap flux", "pdc flux"])):
+            ax = axes[i]
+            m = np.isfinite(time) * np.isfinite(f)
+            m1 = m * (qual == 0)
+            m2 = m * (qual != 0)
+            mu = np.median(f[m1])
+            f1 = (f[m1] / mu - 1) * 1e6
+            ax.plot(time[m1], f1, ".k", ms=3, alpha=0.6)
+            ax.plot(time[m2], (f[m2] / np.median(f[m2]) - 1) * 1e6, ".r", ms=3,
+                    alpha=0.6)
+            ax.set_xlim(xlim)
+            ax.set_ylim(np.min(f1), np.max(f1))
+            ax.annotate("relative "+nm+" [ppm]",
+                        xy=(1, 1), xycoords="axes fraction",
+                        xytext=(-3, -3), textcoords="offset points",
+                        horizontalalignment="right", verticalalignment="top")
+
+        axes[0].set_xticklabels([])
+        axes[1].set_xlabel("time [KBJD]")
+
+        return fig
+
 
 class TargetPixelFile(_datafile):
     """
@@ -673,3 +742,47 @@ class TargetPixelFile(_datafile):
     product = "target_pixel_files"
     suffixes = ["lpd-targ", "spd-targ"]
     filetype = ".fits.gz"
+
+    def plot(self):
+        """
+        Make a simple diagnostic plot of the target pixel light curves. The
+        pixels in the optimal aperture are plotted in black and those outside
+        are plotted in red.
+
+        :return fig:
+            A :class:`matplotlib.Figure` object containing the grid of axes.
+
+        """
+        super(TargetPixelFile, self).plot()
+
+        # Load the data.
+        with self.open() as f:
+            data = f[1].data
+            aperture = f[2].data
+        time, flux = data["time"], data["flux"]
+        nx, ny = flux[0].shape
+
+        # Set up the figures.
+        factor = 3.0
+        dx = factor * nx
+        dy = factor * ny
+        fig, axes = pl.subplots(nx, ny, figsize=(dy, dx))
+        fig.subplots_adjust(left=0.0, right=1.0, bottom=0.0, top=1.0,
+                            wspace=0.0, hspace=0.0)
+
+        # Loop over the pixels.
+        m = np.isfinite(time)
+        xlim = [np.min(time[m]), np.max(time[m])]
+        for xi, yi in product(range(nx), range(ny)):
+            ax = axes[xi, yi]
+            f = flux[:, xi, yi]
+
+            m = np.isfinite(f)
+            ax.plot(time[m], f[m], ".", color="rk"[int(aperture[xi, yi] == 3)],
+                    ms=2)
+
+            ax.set_xlim(xlim)
+            ax.set_xticklabels([])
+            ax.set_yticklabels([])
+
+        return fig
